@@ -5,11 +5,8 @@ use pyo3::{
     types::{PyDict, PyList},
 };
 use pyo3_stub_gen::derive::*;
-use serde_json::{json, Map, Value};
 use statsig_rust::{
-    log_e,
-    statsig_types::{DynamicConfig, Experiment, Layer},
-    DynamicConfigEvaluationOptions, EvaluationDetails, ExperimentEvaluationOptions, FailureDetails,
+    log_e, DynamicConfigEvaluationOptions, ExperimentEvaluationOptions, FailureDetails,
     FeatureGateEvaluationOptions, InitializeDetails, LayerEvaluationOptions,
     ParameterStoreEvaluationOptions, Statsig, StatsigUser,
 };
@@ -99,121 +96,6 @@ impl From<FailureDetails> for FailureDetailsPy {
         }
     }
 }
-#[gen_stub_pyclass]
-#[pyclass(name = "EvaluationDetails", module = "statsig_python_core")]
-#[derive(Clone)]
-pub struct EvaluationDetailsPy {
-    #[pyo3(get)]
-    pub reason: String,
-
-    #[pyo3(get)]
-    pub lcut: Option<u64>,
-
-    #[pyo3(get)]
-    pub received_at: Option<u64>,
-
-    #[pyo3(get)]
-    pub version: Option<u32>,
-}
-
-impl From<EvaluationDetails> for EvaluationDetailsPy {
-    fn from(value: EvaluationDetails) -> Self {
-        EvaluationDetailsPy {
-            reason: value.reason,
-            lcut: value.lcut,
-            received_at: value.received_at,
-            version: value.version,
-        }
-    }
-}
-
-#[gen_stub_pyclass]
-#[pyclass(name = "FeatureGate", module = "statsig_python_core")]
-pub struct FeatureGatePy {
-    #[pyo3(get)]
-    pub name: String,
-
-    #[pyo3(get)]
-    pub value: bool,
-
-    #[pyo3(get)]
-    pub rule_id: String,
-
-    #[pyo3(get)]
-    pub id_type: String,
-
-    #[pyo3(get)]
-    pub details: EvaluationDetailsPy,
-}
-
-#[gen_stub_pyclass]
-#[pyclass(name = "DynamicConfig", module = "statsig_python_core")]
-pub struct DynamicConfigPy {
-    #[pyo3(get)]
-    pub name: String,
-
-    #[pyo3(get)]
-    pub rule_id: String,
-
-    #[pyo3(get)]
-    pub id_type: String,
-
-    #[pyo3(get)]
-    pub value: PyObject,
-
-    #[pyo3(get)]
-    pub details: EvaluationDetailsPy,
-
-    pub inner: DynamicConfig,
-}
-
-#[gen_stub_pyclass]
-#[pyclass(name = "Experiment", module = "statsig_python_core")]
-pub struct ExperimentPy {
-    #[pyo3(get)]
-    pub name: String,
-
-    #[pyo3(get)]
-    pub rule_id: String,
-
-    #[pyo3(get)]
-    pub id_type: String,
-
-    #[pyo3(get)]
-    pub group_name: Option<String>,
-
-    #[pyo3(get)]
-    pub value: PyObject,
-
-    #[pyo3(get)]
-    pub details: EvaluationDetailsPy,
-
-    pub inner: Experiment,
-}
-
-#[gen_stub_pyclass]
-#[pyclass(name = "Layer", module = "statsig_python_core")]
-pub struct LayerPy {
-    #[pyo3(get)]
-    pub name: String,
-
-    #[pyo3(get)]
-    pub rule_id: String,
-
-    #[pyo3(get)]
-    pub group_name: Option<String>,
-
-    #[pyo3(get)]
-    pub allocated_experiment_name: Option<String>,
-
-    #[pyo3(get)]
-    pub value: PyObject,
-
-    #[pyo3(get)]
-    pub details: EvaluationDetailsPy,
-
-    pub inner: Layer,
-}
 
 #[gen_stub_pyclass]
 #[pyclass(name = "ParameterStore", module = "statsig_python_core")]
@@ -229,79 +111,76 @@ pub struct ParameterStorePy {
 #[gen_stub_pymethods]
 #[pymethods]
 impl ParameterStorePy {
-    pub fn get_string(&self, param_name: &str, fallback: String) -> String {
+    pub fn get_string(&self, param_name: &str, fallback: String) -> Option<String> {
         match self.inner_statsig.upgrade() {
-            Some(inner_statsig) => inner_statsig
-                .get_string_parameter_from_store(
-                    &self.user,
-                    &self.name,
-                    param_name,
-                    Some(fallback.clone()),
-                    Some(self.options),
-                )
-                .unwrap_or(fallback),
+            Some(inner_statsig) => inner_statsig.get_string_parameter_from_store(
+                &self.user,
+                &self.name,
+                param_name,
+                Some(fallback),
+                Some(self.options),
+            ),
             None => {
                 log_e!(TAG, "Failed to upgrade Statsig instance");
-                fallback
+                Some(fallback)
             }
         }
     }
 
-    pub fn get_float(&self, param_name: &str, fallback: f64) -> f64 {
+    pub fn get_float(&self, param_name: &str, fallback: f64) -> Option<f64> {
         match self.inner_statsig.upgrade() {
-            Some(inner_statsig) => inner_statsig
-                .get_float_parameter_from_store(
-                    &self.user,
-                    &self.name,
-                    param_name,
-                    Some(fallback),
-                    Some(self.options),
-                )
-                .unwrap_or(fallback),
+            Some(inner_statsig) => inner_statsig.get_float_parameter_from_store(
+                &self.user,
+                &self.name,
+                param_name,
+                Some(fallback),
+                Some(self.options),
+            ),
             None => {
                 log_e!(TAG, "Failed to upgrade Statsig instance");
-                fallback
+                Some(fallback)
             }
         }
     }
 
-    pub fn get_integer(&self, param_name: &str, fallback: i64) -> i64 {
+    pub fn get_integer(&self, param_name: &str, fallback: i64) -> Option<i64> {
         match self.inner_statsig.upgrade() {
-            Some(inner_statsig) => inner_statsig
-                .get_integer_parameter_from_store(
-                    &self.user,
-                    &self.name,
-                    param_name,
-                    Some(fallback),
-                    Some(self.options),
-                )
-                .unwrap_or(fallback),
+            Some(inner_statsig) => inner_statsig.get_integer_parameter_from_store(
+                &self.user,
+                &self.name,
+                param_name,
+                Some(fallback),
+                Some(self.options),
+            ),
             None => {
                 log_e!(TAG, "Failed to upgrade Statsig instance");
-                fallback
+                Some(fallback)
             }
         }
     }
 
-    pub fn get_bool(&self, param_name: &str, fallback: bool) -> bool {
+    pub fn get_bool(&self, param_name: &str, fallback: bool) -> Option<bool> {
         match self.inner_statsig.upgrade() {
-            Some(inner_statsig) => inner_statsig
-                .get_boolean_parameter_from_store(
-                    &self.user,
-                    &self.name,
-                    param_name,
-                    Some(fallback),
-                    Some(self.options),
-                )
-                .unwrap_or(fallback),
+            Some(inner_statsig) => inner_statsig.get_boolean_parameter_from_store(
+                &self.user,
+                &self.name,
+                param_name,
+                Some(fallback),
+                Some(self.options),
+            ),
             None => {
                 log_e!(TAG, "Failed to upgrade Statsig instance");
-                fallback
+                Some(fallback)
             }
         }
     }
 
-    pub fn get_array(&self, py: Python, param_name: &str, fallback: Bound<PyList>) -> PyObject {
+    pub fn get_array(
+        &self,
+        py: Python,
+        param_name: &str,
+        fallback: Bound<PyList>,
+    ) -> Option<PyObject> {
         match self.inner_statsig.upgrade() {
             Some(inner_statsig) => {
                 let result = inner_statsig.get_array_parameter_from_store(
@@ -313,21 +192,26 @@ impl ParameterStorePy {
                 );
                 if let Some(result) = result {
                     match list_of_values_to_py_list(py, &result) {
-                        Ok(list) => list,
-                        Err(_) => fallback.into(),
+                        Ok(list) => Some(list),
+                        Err(_) => Some(fallback.into()),
                     }
                 } else {
-                    fallback.into()
+                    Some(fallback.into())
                 }
             }
             None => {
                 log_e!(TAG, "Failed to upgrade Statsig instance");
-                fallback.into()
+                Some(fallback.into())
             }
         }
     }
 
-    pub fn get_map(&self, py: Python, param_name: &str, fallback: Bound<PyDict>) -> PyObject {
+    pub fn get_map(
+        &self,
+        py: Python,
+        param_name: &str,
+        fallback: Bound<PyDict>,
+    ) -> Option<PyObject> {
         match self.inner_statsig.upgrade() {
             Some(inner_statsig) => {
                 let result = inner_statsig.get_object_parameter_from_store(
@@ -338,65 +222,19 @@ impl ParameterStorePy {
                     Some(self.options),
                 );
                 if let Some(result) = result {
-                    map_to_py_dict(py, &result)
+                    Some(map_to_py_dict(py, &result))
                 } else {
-                    fallback.into()
+                    Some(fallback.into())
                 }
             }
             None => {
                 log_e!(TAG, "Failed to upgrade Statsig instance");
-                fallback.into()
+                Some(fallback.into())
             }
         }
     }
 }
 
-macro_rules! impl_get_methods {
-    ($struct_name:ident) => {
-        #[gen_stub_pymethods]
-        #[pymethods]
-        impl $struct_name {
-            pub fn get_bool(&self, param_name: &str, fallback: bool) -> bool {
-                self.inner.get(param_name, fallback)
-            }
-
-            pub fn get_float(&self, param_name: &str, fallback: f64) -> f64 {
-                self.inner.get(param_name, fallback)
-            }
-
-            pub fn get_integer(&self, param_name: &str, fallback: i64) -> i64 {
-                self.inner.get(param_name, fallback)
-            }
-
-            pub fn get_string(&self, param_name: &str, fallback: String) -> String {
-                self.inner.get(param_name, fallback)
-            }
-
-            pub fn get_array_json(&self, param_name: &str, fallback: String) -> String {
-                let result = match self.inner.get_opt::<Vec<Value>>(param_name) {
-                    Some(v) => v,
-                    None => return fallback,
-                };
-
-                json!(result).to_string()
-            }
-
-            pub fn get_object_json(&self, param_name: &str, fallback: String) -> String {
-                let result = match self.inner.get_opt::<Map<String, Value>>(param_name) {
-                    Some(v) => v,
-                    None => return fallback,
-                };
-
-                json!(result).to_string()
-            }
-        }
-    };
-}
-
-impl_get_methods!(DynamicConfigPy);
-impl_get_methods!(ExperimentPy);
-impl_get_methods!(LayerPy);
-
 #[gen_stub_pyclass]
 #[pyclass(name = "FeatureGateEvaluationOptions", module = "statsig_python_core")]
 #[derive(FromPyObject)]
