@@ -1,7 +1,10 @@
 use crate::{
     evaluation::evaluation_types::{AnyConfigEvaluation, GateEvaluation, LayerEvaluation},
-    specs_response::param_store_types::Parameter,
-    specs_response::spec_types::SessionReplayTrigger,
+    gcir::gcir_formatter::EvaluatedKeys,
+    specs_response::{
+        param_store_types::Parameter,
+        spec_types::{SessionReplayPrivacySetting, SessionReplayTrigger},
+    },
     user::{StatsigUserInternal, StatsigUserLoggable},
 };
 
@@ -23,7 +26,7 @@ pub struct InitializeResponse {
     pub sdk_info: HashMap<String, String>,
     #[serde(rename = "sdkParams")]
     pub sdk_params: HashMap<String, String>,
-    pub evaluated_keys: HashMap<String, String>,
+    pub evaluated_keys: EvaluatedKeys,
     pub param_stores: HashMap<String, HashMap<String, Parameter>>,
     pub can_record_session: Option<bool>,
     pub session_recording_rate: Option<f64>,
@@ -31,7 +34,9 @@ pub struct InitializeResponse {
     pub passes_session_recording_targeting: Option<bool>,
     pub session_recording_event_triggers: Option<HashMap<String, SessionReplayTrigger>>,
     pub session_recording_exposure_triggers: Option<HashMap<String, SessionReplayTrigger>>,
+    pub session_recording_privacy_settings: Option<SessionReplayPrivacySetting>,
     pub pa_hash: Option<String>,
+    pub full_checksum: Option<String>,
 }
 
 impl InitializeResponse {
@@ -45,6 +50,31 @@ impl InitializeResponse {
             hash_used: Default::default(),
             user: user.to_loggable(),
             sdk_params: Default::default(),
+            evaluated_keys: EvaluatedKeys::default(),
+            sdk_info: Default::default(),
+            param_stores: Default::default(),
+            can_record_session: Default::default(),
+            session_recording_rate: Default::default(),
+            recording_blocked: Default::default(),
+            passes_session_recording_targeting: Default::default(),
+            session_recording_event_triggers: Default::default(),
+            session_recording_exposure_triggers: Default::default(),
+            session_recording_privacy_settings: Default::default(),
+            pa_hash: user.get_hashed_private_attributes(),
+            full_checksum: Default::default(),
+        }
+    }
+
+    pub fn blank_without_user() -> Self {
+        Self {
+            feature_gates: Default::default(),
+            dynamic_configs: Default::default(),
+            layer_configs: Default::default(),
+            time: 0,
+            has_updates: false,
+            hash_used: Default::default(),
+            user: StatsigUserLoggable::default(),
+            sdk_params: Default::default(),
             evaluated_keys: Default::default(),
             sdk_info: Default::default(),
             param_stores: Default::default(),
@@ -54,7 +84,9 @@ impl InitializeResponse {
             passes_session_recording_targeting: Default::default(),
             session_recording_event_triggers: Default::default(),
             session_recording_exposure_triggers: Default::default(),
-            pa_hash: user.get_hashed_private_attributes(),
+            session_recording_privacy_settings: Default::default(),
+            pa_hash: None,
+            full_checksum: Default::default(),
         }
     }
 }
