@@ -43,7 +43,7 @@ pub mod hashing;
 pub mod init_details;
 pub mod instance_registry;
 pub mod interned_string;
-pub mod interned_value_store;
+pub mod interned_values;
 pub mod logging_utils;
 pub mod networking;
 pub mod output_logger;
