@@ -14,12 +14,74 @@ lazy_static::lazy_static! {
     static ref OPS_STATS: OpsStatsForInstance = OpsStatsForInstance::new();
 }
 
-const PROTO_SPECS_BYTES: &[u8] = include_bytes!("../../../tests/data/eval_proj_dcs.pb.br");
-const JSON_SPECS_BYTES: &[u8] = include_bytes!("../../../tests/data/eval_proj_dcs.json");
+const EVAL_PROJ_PROTO_BYTES: &[u8] = include_bytes!("../../../tests/data/eval_proj_dcs.pb.br");
+const EVAL_PROJ_JSON_BYTES: &[u8] = include_bytes!("../../../tests/data/eval_proj_dcs.json");
+
+const DEMO_PROJ_PROTO_BYTES: &[u8] = include_bytes!("../../../tests/data/demo_proj_dcs.pb.br");
+const DEMO_PROJ_JSON_BYTES: &[u8] = include_bytes!("../../../tests/data/demo_proj_dcs.json");
+
+const PERF_PROJ_PROTO_BYTES: &[u8] = include_bytes!("../../../tests/data/perf_proj_dcs.pb.br");
+const PERF_PROJ_JSON_BYTES: &[u8] = include_bytes!("../../../tests/data/perf_proj_dcs.json");
+
+#[test]
+fn test_demo_proj_top_level_fields_present() {
+    let proto_specs = get_deserialized_specs(DEMO_PROJ_PROTO_BYTES);
+    let proto_specs_json: Value = serde_json::to_value(proto_specs).unwrap();
+    let json: Value = serde_json::from_slice(DEMO_PROJ_JSON_BYTES).unwrap();
+
+    let proto_specs_keys = proto_specs_json
+        .as_object()
+        .unwrap()
+        .keys()
+        .map(|k| k.as_str())
+        .collect::<Vec<&str>>();
+    let json_keys = json
+        .as_object()
+        .unwrap()
+        .keys()
+        .map(|k| k.as_str())
+        .collect::<Vec<&str>>();
+
+    for key in json_keys {
+        assert!(
+            proto_specs_keys.contains(&key),
+            "Key '{}' not found in proto specs",
+            key
+        );
+    }
+}
+
+#[test]
+fn test_perf_proj_top_level_fields_present() {
+    let proto_specs = get_deserialized_specs(PERF_PROJ_PROTO_BYTES);
+    let proto_specs_json: Value = serde_json::to_value(proto_specs).unwrap();
+    let json: Value = serde_json::from_slice(PERF_PROJ_JSON_BYTES).unwrap();
+
+    let proto_specs_keys = proto_specs_json
+        .as_object()
+        .unwrap()
+        .keys()
+        .map(|k| k.as_str())
+        .collect::<Vec<&str>>();
+    let json_keys = json
+        .as_object()
+        .unwrap()
+        .keys()
+        .map(|k| k.as_str())
+        .collect::<Vec<&str>>();
+
+    for key in json_keys {
+        assert!(
+            proto_specs_keys.contains(&key),
+            "Key '{}' not found in proto specs",
+            key
+        );
+    }
+}
 
 #[test]
 fn test_top_level_json_vs_proto() {
-    let mut proto_specs = get_deserialized_specs();
+    let mut proto_specs = get_deserialized_specs(EVAL_PROJ_PROTO_BYTES);
 
     proto_specs.feature_gates.clear();
     proto_specs.dynamic_configs.clear();
@@ -31,7 +93,7 @@ fn test_top_level_json_vs_proto() {
     let mut proto_specs_val: serde_json::Map<String, Value> =
         serde_json::from_str(&proto_specs_string).unwrap();
 
-    let mut json_string = String::from_utf8(JSON_SPECS_BYTES.to_vec()).unwrap();
+    let mut json_string = String::from_utf8(EVAL_PROJ_JSON_BYTES.to_vec()).unwrap();
 
     // proto defaults to null for empty additionalValues
     json_string = json_string.replace(r#""additionalValues":{}"#, r#""additionalValues":null"#);
@@ -171,22 +233,26 @@ fn test_a_param_store_json_vs_proto() {
     assert_json_diff::assert_json_matches!(proto_spec, json_spec, get_json_compare_config());
 }
 
-fn deserialize_from(current_specs: &mut SpecsResponseFull, next_specs: &mut SpecsResponseFull) {
-    let bytes = PROTO_SPECS_BYTES.to_vec();
+fn deserialize_from(
+    bytes: &[u8],
+    current_specs: &mut SpecsResponseFull,
+    next_specs: &mut SpecsResponseFull,
+) {
+    let bytes = bytes.to_vec();
     let mut data = ResponseData::from_bytes(bytes);
     deserialize_protobuf(&OPS_STATS, current_specs, next_specs, &mut data).unwrap();
 }
 
-fn get_deserialized_specs() -> SpecsResponseFull {
+fn get_deserialized_specs(bytes: &[u8]) -> SpecsResponseFull {
     let mut current_specs = SpecsResponseFull::default();
     let mut next_specs = SpecsResponseFull::default();
-    deserialize_from(&mut current_specs, &mut next_specs);
+    deserialize_from(bytes, &mut current_specs, &mut next_specs);
     next_specs
 }
 
 fn get_proto_spec(top_level: &str, name: &str) -> serde_json::Map<String, Value> {
     let name = InternedString::from_str_ref(name);
-    let mut proto_specs = get_deserialized_specs();
+    let mut proto_specs = get_deserialized_specs(EVAL_PROJ_PROTO_BYTES);
 
     let ptr = match top_level {
         "feature_gates" => proto_specs.feature_gates.remove(&name).unwrap(),
@@ -203,7 +269,7 @@ fn get_proto_spec(top_level: &str, name: &str) -> serde_json::Map<String, Value>
 
 fn get_proto_spec_param_store(name: &str) -> serde_json::Map<String, Value> {
     let name = InternedString::from_str_ref(name);
-    let proto_specs = get_deserialized_specs();
+    let proto_specs = get_deserialized_specs(EVAL_PROJ_PROTO_BYTES);
     let ptr = proto_specs.param_stores.unwrap().remove(&name).unwrap();
     match serde_json::to_value(ptr).expect("Failed to convert SpecPointer to Value") {
         Value::Object(obj) => obj,
@@ -215,8 +281,8 @@ fn get_proto_spec_param_store(name: &str) -> serde_json::Map<String, Value> {
 fn get_proto_spec_resynced(top_level: &str, name: &str) -> serde_json::Map<String, Value> {
     let mut specs_one = SpecsResponseFull::default();
     let mut specs_two = SpecsResponseFull::default();
-    deserialize_from(&mut specs_one, &mut specs_two);
-    deserialize_from(&mut specs_two, &mut specs_one);
+    deserialize_from(EVAL_PROJ_PROTO_BYTES, &mut specs_one, &mut specs_two);
+    deserialize_from(EVAL_PROJ_PROTO_BYTES, &mut specs_two, &mut specs_one);
 
     let name = InternedString::from_str_ref(name);
     let ptr = match top_level {
@@ -233,7 +299,7 @@ fn get_proto_spec_resynced(top_level: &str, name: &str) -> serde_json::Map<Strin
 }
 
 fn get_json_spec(top_level: &str, name: &str) -> serde_json::Map<String, Value> {
-    let json_specs: HashMap<String, Value> = serde_json::from_slice(JSON_SPECS_BYTES).unwrap();
+    let json_specs: HashMap<String, Value> = serde_json::from_slice(EVAL_PROJ_JSON_BYTES).unwrap();
     let value = json_specs
         .get(top_level)
         .unwrap()
