@@ -814,6 +814,18 @@ impl Statsig {
         )
     }
 
+    pub fn get_parameter_store_for_user(
+        &self,
+        user: &StatsigUser,
+        parameter_store_name: &str,
+    ) -> ParameterStore<'_> {
+        self.get_parameter_store_with_user_and_options(
+            Some(user),
+            parameter_store_name,
+            ParameterStoreEvaluationOptions::default(),
+        )
+    }
+
     pub fn get_parameter_store_with_options(
         &self,
         parameter_store_name: &str,
@@ -1436,7 +1448,7 @@ impl Statsig {
                         id_type,
                         group_name,
                         details,
-                        is_experiment_active: spec_pointer.inner.is_active.unwrap_or(false),
+                        is_experiment_active: spec_pointer.as_spec_ref().is_active.unwrap_or(false),
                         __evaluation: None,
                     };
                 }
@@ -1468,7 +1480,7 @@ impl Statsig {
                         id_type,
                         group_name,
                         details,
-                        is_experiment_active: spec_pointer.inner.is_active.unwrap_or(false),
+                        is_experiment_active: spec_pointer.as_spec_ref().is_active.unwrap_or(false),
                         __evaluation: None,
                     };
                 }
@@ -1543,7 +1555,12 @@ impl Statsig {
             );
         };
 
-        if let Some(rule) = exp.inner.rules.iter().find(|rule| rule_predicate(rule)) {
+        if let Some(rule) = exp
+            .as_spec_ref()
+            .rules
+            .iter()
+            .find(|rule| rule_predicate(rule))
+        {
             return result_factory(
                 Some(exp),
                 Some(rule),
