@@ -1,17 +1,16 @@
 mod utils;
 use serde_json::json;
 use statsig_rust::{output_logger, Statsig, StatsigOptions, StatsigUser};
-use std::{
-    collections::{HashMap, HashSet},
-    sync::Arc,
-};
+use std::{collections::HashMap, sync::Arc};
 use utils::mock_scrapi::{Endpoint, EndpointStub, Method, MockScrapi, StubData};
 
-use crate::utils::helpers::load_contents;
+use crate::utils::{
+    helpers::load_contents, mock_data_store::MockDataStore, mock_log_provider::MockLogProvider,
+};
 
-const KNOWN_CHECKSUM: &str = "2556334789679907000" /* eval_proj_dcs.json['checksum'] */;
+const KNOWN_CHECKSUM: &str = "8506699639233708000" /* eval_proj_dcs.json['checksum'] */;
 const EVAL_PROJ_GATE_COUNT: usize = 69 /* eval_proj_dcs.json['feature_gates'].filter(g => g.entity === feature_gate).length */;
-const EVAL_PROJ_DC_COUNT: usize = 7 /* eval_proj_dcs.json['dynamic_configs'].filter(dc => dc.entity === dynamic_config).length */;
+const EVAL_PROJ_DC_COUNT: usize = 9 /* eval_proj_dcs.json['dynamic_configs'].filter(dc => dc.entity === dynamic_config).length */;
 const DEMO_PROJ_GATE_COUNT: usize = 7 /* demo_proj_dcs.json['feature_gates'].filter(g => g.entity === feature_gate).length */;
 
 const EVAL_PROJ_PROTO_BYTES: &[u8] = include_bytes!("../tests/data/eval_proj_dcs.pb.br");
@@ -43,6 +42,29 @@ async fn test_proto_specs_initialize() {
     assert!(gate);
 }
 
+#[tokio::test]
+async fn test_proto_specs_request_accept_encoding_header() {
+    std::env::set_var("STATSIG_RUNNING_TESTS", "true");
+
+    let options = make_statsig_opts(DELAYED_SYNC_INTERVAL_MS);
+    let (mock_scrapi, statsig) = setup("secret-proto-specs-accept-encoding", Some(options)).await;
+
+    statsig.initialize().await.unwrap();
+
+    let requests = mock_scrapi.get_requests_for_endpoint(Endpoint::DownloadConfigSpecs);
+    let request = requests
+        .first()
+        .expect("expected at least one request for download config specs");
+
+    let accept_encoding = request
+        .headers
+        .get("accept-encoding")
+        .and_then(|header| header.to_str().ok())
+        .unwrap_or("");
+
+    assert_eq!(accept_encoding, "statsig-br, gzip, deflate, br");
+}
+
 #[tokio::test]
 async fn test_proto_specs_syncing() {
     std::env::set_var("STATSIG_RUNNING_TESTS", "true");
@@ -149,6 +171,33 @@ async fn test_json_then_proto() {
     assert_gate_count!(statsig, EVAL_PROJ_GATE_COUNT);
 }
 
+#[tokio::test]
+async fn test_proto_with_data_store() {
+    std::env::set_var("STATSIG_RUNNING_TESTS", "true");
+
+    let log_provider = Arc::new(MockLogProvider::new());
+    let data_store = Arc::new(MockDataStore::new(true));
+
+    let options = StatsigOptions {
+        data_store: Some(data_store.clone()),
+        specs_sync_interval_ms: Some(INSTANT_SYNC_INTERVAL_MS),
+        fallback_to_statsig_api: Some(true),
+        output_log_level: Some(output_logger::LogLevel::Debug),
+        output_logger_provider: Some(log_provider.clone()),
+        ..Default::default()
+    };
+    let (_mock_scrapi, statsig) =
+        setup("secret-proto-then-json-with-data-store", Some(options)).await;
+
+    statsig.initialize().await.unwrap();
+
+    assert_eventually!(|| data_store.num_get_calls() > 3);
+    assert!(data_store.num_set_calls() == 0);
+
+    let error_logs = log_provider.get_error_logs();
+    assert!(error_logs.is_empty());
+}
+
 async fn setup(key: &str, options_override: Option<StatsigOptions>) -> (MockScrapi, Statsig) {
     let mock_scrapi = MockScrapi::new().await;
 
@@ -167,7 +216,6 @@ async fn setup(key: &str, options_override: Option<StatsigOptions>) -> (MockScra
         Some(Arc::new(StatsigOptions {
             specs_url: Some(mock_scrapi.url_for_endpoint(Endpoint::DownloadConfigSpecs)),
             log_event_url: Some(mock_scrapi.url_for_endpoint(Endpoint::LogEvent)),
-            experimental_flags: Some(HashSet::from(["enable_proto_spec_support".to_string()])),
             ..options_override.unwrap_or_default()
         })),
     );
